*check-dns.ps1*
================

This PowerShell script measures and prints the DNS resolution speed by using 200 popular domains.

Parameters
----------
```powershell
PS> ./check-dns.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-dns.ps1
✅ DNS resolves 156.5 domains per second

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Check DNS resolution 
.DESCRIPTION
	This PowerShell script measures and prints the DNS resolution speed by using 200 popular domains.
.EXAMPLE
	PS> ./check-dns.ps1
	✅ DNS resolves 156.5 domains per second
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>
 
try {
	Write-Progress "⏳ Resolving 200 popular domain names..."
	$table = Import-CSV "$PSScriptRoot/../Data/popular-domains.csv"
	$numRows = $table.Length

	$stopWatch = [system.diagnostics.stopwatch]::startNew()
	if ($IsLinux) {
foreach($row in $table){$nop=dig $row.Domain +short}
	} else {
foreach($row in $table){$nop=Resolve-DNSName $row.Domain}
	}
	Write-Progress -completed "."
	[float]$elapsed = $stopWatch.Elapsed.TotalSeconds
	$average = [math]::round($numRows / $elapsed, 1)
	if ($average -lt 10.0) {
		Write-Output "⚠️ DNS resolves $average domains per second only"
	} else {  
		Write-Output "✅ DNS resolves $average domains per second"
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of check-dns.ps1 as of 08/06/2023 21:36:05)*
