*check-uptime.ps1*
================

This PowerShell script queries the computer's uptime and prints it.

Parameters
----------
```powershell
PS> ./check-uptime.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-uptime.ps1
✅ Up for 2 days, 20 hours, 10 minutes

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks the uptime 
.DESCRIPTION
	This PowerShell script queries the computer's uptime and prints it.
.EXAMPLE
	PS> ./check-uptime.ps1
	✅ Up for 2 days, 20 hours, 10 minutes
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	if ($IsLinux) {
		$Uptime = (Get-Uptime)
	} else {
		$BootTime = Get-WinEvent -ProviderName eventlog | Where-Object {$_.Id -eq 6005} | Select-Object TimeCreated -First 1 
		$Uptime = New-TimeSpan -Start $BootTime.TimeCreated.Date -End (Get-Date)
	}
	$Reply = "✅ Up for "
	$Days = $Uptime.Days
	if ($Days -eq "1") {
		$Reply += "1 day, "
	} elseif ($Days -ne "0") {
		$Reply += "$Days days, "
	}

	$Hours = $Uptime.Hours
	if ($Hours -eq "1") {
		$Reply += "1 hour, "
	} elseif ($Hours -ne "0") {
		$Reply += "$Hours hours, "
	}

	$Minutes = $Uptime.Minutes 
	if ($Minutes -eq "1") {
		$Reply += "1 minute"
	} else {
		$Reply += "$Minutes minutes"
	}
	Write-Host $Reply
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of check-uptime.ps1 as of 08/06/2023 21:36:06)*
