*check-vpn.ps1*
================

This PowerShell script queries and prints the status of the VPN connection(s).

Parameters
----------
```powershell
PS> ./check-vpn.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-vpn.ps1
✅ VPN to NASA L2TP is disconnected

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks the VPN status
.DESCRIPTION
	This PowerShell script queries and prints the status of the VPN connection(s).
.EXAMPLE
	PS> ./check-vpn.ps1
	✅ VPN to NASA L2TP is disconnected
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$NoVPN = $true
	if ($IsLinux) {
		# TODO
	} else {
		$Connections = Get-VPNConnection
		foreach($Connection in $Connections) {
			Write-Host "✅ VPN to $($Connection.Name) is $($Connection.ConnectionStatus.ToLower())"
			$NoVPN = $false
		}
	}
	if ($NoVPN) { Write-Host "⚠️ No VPN configured" }
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of check-vpn.ps1 as of 08/06/2023 21:36:06)*
