*count-lines-of-code.ps1*
================

This PowerShell script counts the number of code lines in a folder (including subfolders).

Parameters
----------
```powershell
PS> ./count-lines-of-code.ps1 [[-Folder] <String>] [<CommonParameters>]

-Folder <String>
    Specifies the path to the folder
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./count-lines-of-code.ps1 .
⏳ Counting lines at 📂C:\PowerShell\Scripts ...
✔️ 📂Scripts contains 15287 lines of code in 485 files (took 1 sec)

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Counts lines of code
.DESCRIPTION
	This PowerShell script counts the number of code lines in a folder (including subfolders).
.PARAMETER Folder
	Specifies the path to the folder
.EXAMPLE
	PS> ./count-lines-of-code.ps1 .
	⏳ Counting lines at 📂C:\PowerShell\Scripts ...
	✔️ 📂Scripts contains 15287 lines of code in 485 files (took 1 sec)
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$Folder = "")

try {
	if ($Folder -eq "" ) { $Folder = read-host "Enter the path to the folder" }

	$StopWatch = [system.diagnostics.stopwatch]::startNew()
	$Folder = Resolve-Path "$Folder"
	"⏳ Counting lines at 📂$Folder ..."

	[int]$Files = [int]$CodeLines = 0
	Get-ChildItem -Path $Folder -Include *.c,*.h,*.cpp,*.hpp,*.java,*.ps1 -Recurse | ForEach-Object {
		$FileStats = Get-Content $_.FullName | Measure-Object -line
		$CodeLines += $FileStats.Lines
		$Files++
	}

	$FolderName = (Get-Item "$Folder").Name
	[int]$Elapsed = $StopWatch.Elapsed.TotalSeconds
	"✔️ 📂$FolderName contains $CodeLines lines of code in $Files files (took $Elapsed sec)" 
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of count-lines-of-code.ps1 as of 08/06/2023 21:36:07)*
