*list-latest-tags.ps1*
================

This PowerShell script lists the latest tags in all Git repositories in the specified folder.

Parameters
----------
```powershell
PS> ./list-latest-tags.ps1 [[-ParentDir] <String>] [<CommonParameters>]

-ParentDir <String>
    Specifies the path to the parent folder
    
    Required?                    false
    Position?                    1
    Default value                "$PWD"
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-latest-tags C:\MyRepos

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists the latests tags in all Git repositories in a folder
.DESCRIPTION
	This PowerShell script lists the latest tags in all Git repositories in the specified folder.
.PARAMETER ParentDir
	Specifies the path to the parent folder
.EXAMPLE
	PS> ./list-latest-tags C:\MyRepos
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$ParentDir = "$PWD")

try {
	if (-not(test-path "$ParentDir" -pathType container)) { throw "Can't access directory: $ParentDir" }

	$Null = (git --version)
	if ($lastExitCode -ne "0") { throw "Can't execute 'git' - make sure Git is installed and available" }

	$Folders = (get-childItem "$ParentDir" -attributes Directory)
	$FolderCount = $Folders.Count
	$ParentDirName = (get-item "$ParentDir").Name
	"Found $FolderCount subfolders in 📂$ParentDirName..."

	foreach ($Folder in $Folders) {
		$FolderName = (get-item "$Folder").Name

#		& git -C "$Folder" fetch --tags
#		if ($lastExitCode -ne "0") { throw "'git fetch --tags' failed" }

		$LatestTagCommitID = (git -C "$Folder" rev-list --tags --max-count=1)
		$LatestTag = (git -C "$Folder" describe --tags $LatestTagCommitID)
		"* $FolderName $LatestTag ($LatestTagCommitID)"
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-latest-tags.ps1 as of 08/06/2023 21:36:13)*
