*list-memos.ps1*
================

This PowerShell script lists all memo entries in Memos.csv in your home folder.

Parameters
----------
```powershell
PS> ./list-memos.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-memos.ps1

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists your memo entries
.DESCRIPTION
	This PowerShell script lists all memo entries in Memos.csv in your home folder.
.EXAMPLE
	PS> ./list-memos.ps1
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>


try {
	$Path = "~/Memos.csv"
	if (Test-Path "$Path" -pathType leaf) {
		write-progress "Reading $Path ..."
		$Table = Import-CSV "$Path"
		write-progress -completed "Reading $Path"

		""
		"Time                  Text"
		"----                  ----"
		foreach($Row in $Table) {
			$Time = $Row.Time
			$Text = $Row.Text
			"$Time  $Text"
		}
	} else {
		"Sorry, no memos saved yet"
		exit 1
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-memos.ps1 as of 08/06/2023 21:36:13)*
