*list-news.ps1*
================

This PowerShell script lists the latest news by using RSS (Really Simple Syndication) feeds.

Parameters
----------
```powershell
PS> ./list-news.ps1 [[-RSS_URL] <String>] [[-MaxLines] <Int32>] [[-Speed] <Int32>] [<CommonParameters>]

-RSS_URL <String>
    Specifies the URL to the RSS feed (Yahoo News by default)
    
    Required?                    false
    Position?                    1
    Default value                https://yahoo.com/news/rss/world
    Accept pipeline input?       false
    Accept wildcard characters?  false

-MaxLines <Int32>
    Specifies the maximum number of lines to list (24 by default)
    
    Required?                    false
    Position?                    2
    Default value                24
    Accept pipeline input?       false
    Accept wildcard characters?  false

-Speed <Int32>
    Specifies the speed to write the text (10 ms by default)
    
    Required?                    false
    Position?                    3
    Default value                10
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-news.ps1
❇️ Deadly Mediterranean wildfires kill more than 40
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	List the latest news
.DESCRIPTION
	This PowerShell script lists the latest news by using RSS (Really Simple Syndication) feeds.
.PARAMETER RSS_URL
	Specifies the URL to the RSS feed (Yahoo News by default)
.PARAMETER MaxLines
	Specifies the maximum number of lines to list (24 by default)
.PARAMETER Speed
        Specifies the speed to write the text (10 ms by default)
.EXAMPLE
	PS> ./list-news.ps1
	❇️ Deadly Mediterranean wildfires kill more than 40
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$RSS_URL = "https://yahoo.com/news/rss/world", [int]$MaxLines = 24, [int]$Speed = 10)

try {
	[xml]$Content = (Invoke-WebRequest -URI $RSS_URL -useBasicParsing).Content
	[int]$Count = 1
	foreach ($Item in $Content.rss.channel.item) {
		& "$PSScriptRoot/write-typewriter.ps1" "❇️ $($Item.title)" $Speed
		if ($Count++ -eq $MaxLines) { break }
	}
	$Source = $Content.rss.channel.title
	$Date = $Content.rss.channel.pubDate
	$Date = $Date -Replace "Mon, ",""
	$Date = $Date -Replace "Tue, ",""
	$Date = $Date -Replace "Wed, ",""
	$Date = $Date -Replace "Thu, ",""
	$Date = $Date -Replace "Fri, ",""
	$Date = $Date -Replace "Sat, ",""
	$Date = $Date -Replace "Sun, ",""
	"(by $Source as of $Date)"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-news.ps1 as of 08/06/2023 21:36:13)*
