*new-qrcode.ps1*
================

This PowerShell script generates a new QR code image file.

Parameters
----------
```powershell
PS> ./new-qrcode.ps1 [[-Text] <String>] [[-ImageSize] <String>] [<CommonParameters>]

-Text <String>
    Specifies the text to use
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

-ImageSize <String>
    Specifies the image size (width x height)
    
    Required?                    false
    Position?                    2
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./new-qrcode.ps1 "Fasten seatbelt" 500x500

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Generates a QR code
.DESCRIPTION
	This PowerShell script generates a new QR code image file.
.PARAMETER Text
	Specifies the text to use
.PARAMETER ImageSize
	Specifies the image size (width x height)
.EXAMPLE
	PS> ./new-qrcode.ps1 "Fasten seatbelt" 500x500
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$Text = "", [string]$ImageSize = "")

try {
	if ($Text -eq "") { $Text = read-host "Enter text or URL" }
	if ($ImageSize -eq "") { $ImageSize = read-host "Enter image size (e.g. 500x500)" }

	$ECC = "M" # can be L, M, Q, H
	$QuietZone = 1
	$ForegroundColor = "000000"
	$BackgroundColor = "ffffff"
	$FileFormat = "jpg"
        if ($IsLinux) {
                $PathToPics = Resolve-Path "$HOME/Pictures"
        } else {
                $PathToPics = [Environment]::GetFolderPath('MyPictures')
        }
        if (-not(Test-Path "$PathToPics" -pathType container)) {
                throw "Pictures folder at 📂$Path doesn't exist (yet)"
        }
	$NewFile = "$PathToPics/QR_code.jpg"

	$WebClient = new-object System.Net.WebClient
	$WebClient.DownloadFile(("http://api.qrserver.com/v1/create-qr-code/?data=" + $Text + "&ecc=" + $ECC +`
		"&size=" + $ImageSize + "&qzone=" + $QuietZone + `
		"&color=" + $ForegroundColor + "&bgcolor=" + $BackgroundColor.Text + `
		"&format=" + $FileFormat), $NewFile)

	"✔️ saved new QR code image file to: $NewFile"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of new-qrcode.ps1 as of 08/06/2023 21:36:14)*
