*speak-checklist.ps1*
================

This PowerShell script speaks the given checklist by text-to-speech (TTS).

Parameters
----------
```powershell
PS> ./speak-checklist.ps1 [[-Name] <String>] [<CommonParameters>]

-Name <String>
    Specifies the name of the checklist
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./speak-checklist.ps1

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Speaks a checklist by text-to-speech
.DESCRIPTION
	This PowerShell script speaks the given checklist by text-to-speech (TTS).
.PARAMETER Name
	Specifies the name of the checklist
.EXAMPLE
	PS> ./speak-checklist.ps1
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$Name = "")

try {
	if ($Name -eq "") { $Name = Read-Host "Enter the name of the checklist" }

	$Lines = Get-Content -path "$PSScriptRoot/../Data/Checklists/$Name.txt"
	clear-host
	$Step = 1
	foreach($Line in $Lines) {
		if ($Line -like "HEAD*") { & "$PSScriptRoot/write-big.ps1" "$($Line.substring(5))"; continue }

		""			
		& "$PSScriptRoot/speak-english.ps1" "$($Step). $Line"
		$Dummy = Read-Host "    Say <Check> or press <Return> to continue"
		$Step++
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of speak-checklist.ps1 as of 08/06/2023 21:36:17)*
