*speak-text.ps1*
================

This PowerShell script speaks the given text by the default text-to-speech (TTS) voice.

Parameters
----------
```powershell
PS> ./speak-text.ps1 [[-text] <String>] [<CommonParameters>]

-text <String>
    Specifies the text to read
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./speak-text.ps1 Hi

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Speaks text by the default text-to-speech voice
.DESCRIPTION
	This PowerShell script speaks the given text by the default text-to-speech (TTS) voice.
.PARAMETER text
	Specifies the text to read
.EXAMPLE
	PS> ./speak-text.ps1 Hi
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "")

try {
	if ($text -eq "") { $text = Read-Host "Enter the text to speak" }

	$Voice = new-object -ComObject SAPI.SPVoice
	[void]$Voice.Speak($text)
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of speak-text.ps1 as of 08/06/2023 21:36:17)*
