*switch-tabs.ps1*
================

This PowerShell script switches browser tabs automatically every <n> seconds (by pressing Ctrl + PageDown).

Parameters
----------
```powershell
PS> ./switch-tabs.ps1 [[-Interval] <Int32>] [<CommonParameters>]

-Interval <Int32>
    Specifies the switch interval in seconds (10 sec per default)
    
    Required?                    false
    Position?                    1
    Default value                10
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./switch-tabs

```

Notes
-----
Author: Markus Fleschutz / License: CC0

Related Links
-------------
https://github.com/fleschutz/talk2windows

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Switches browser tabs
.DESCRIPTION
	This PowerShell script switches browser tabs automatically every <n> seconds (by pressing Ctrl + PageDown).
.PARAMETER Interval
        Specifies the switch interval in seconds (10 sec per default)
.EXAMPLE
	PS> ./switch-tabs
.NOTES
	Author: Markus Fleschutz / License: CC0
.LINK
	https://github.com/fleschutz/talk2windows
#>

param([int]$Interval = 10) # in seconds

try {
	Write-Host "⏳ Switching browser tabs automatically every $Interval seconds..."
	Write-Host "   (click into the browser window to activate it, press Ctrl + C here to stop it)"
	$obj = New-Object -com wscript.shell
	while ($true) {
		$obj.SendKeys("^{PGDN}")
		Start-Sleep -seconds $Interval
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of switch-tabs.ps1 as of 08/06/2023 21:36:17)*
